@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2010, 2013 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2010-2013 Graeme Gott <graeme@gottcode.org>
 
-#ifndef RTF_TOKENIZER_H
-#define RTF_TOKENIZER_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef FOCUSWRITER_RTF_TOKENIZER_H
+#define FOCUSWRITER_RTF_TOKENIZER_H
 
 #include <QByteArray>
 #include <QCoreApplication>
@@ -37,7 +24,7 @@ class RtfTokenizer
 	Q_DECLARE_TR_FUNCTIONS(RtfTokenizer)
 
 public:
-	RtfTokenizer();
+	explicit RtfTokenizer();
 
 	bool hasNext() const;
 	bool hasValue() const;
@@ -89,4 +76,4 @@ inline qint32 RtfTokenizer::value() const
 	return m_value;
 }
 
-#endif
+#endif // FOCUSWRITER_RTF_TOKENIZER_H
