@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2017 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "theme.h"
 
@@ -43,76 +30,78 @@ void qt_blurImage(QPainter* p, QImage& blurImage, qreal radius, bool quality, bo
 
 namespace
 {
-	QColor averageImage(const QString& filename, const QColor& fallback)
-	{
-		QImageReader reader(filename);
-		if (!reader.canRead()) {
-			return fallback;
-		}
 
-		QImage image(reader.size(), QImage::Format_ARGB32_Premultiplied);
-		image.fill(fallback.rgb());
-		{
-			QPainter painter(&image);
-			painter.drawImage(0, 0, reader.read());
-		}
-		const unsigned int width = image.width();
-		const unsigned int height = image.height();
-
-		quint64 sum_r = 0;
-		quint64 sum_g = 0;
-		quint64 sum_b = 0;
-		quint64 sum_a = 0;
-
-		for (unsigned int y = 0; y < height; ++y) {
-			const QRgb* scanline = reinterpret_cast<const QRgb*>(image.scanLine(y));
-			for (unsigned int x = 0; x < width; ++x) {
-				QRgb pixel = scanline[x];
-				sum_r += qRed(pixel);
-				sum_g += qGreen(pixel);
-				sum_b += qBlue(pixel);
-				sum_a += qAlpha(pixel);
-			}
-		}
-
-		const qreal divisor = 1.0 / (width * height);
-		return QColor(sum_r * divisor, sum_g * divisor, sum_b * divisor, sum_a * divisor);
+QColor averageImage(const QString& filename, const QColor& fallback)
+{
+	QImageReader reader(filename);
+	if (!reader.canRead()) {
+		return fallback;
 	}
 
-	QString checksumName(const QString& image)
+	QImage image(reader.size(), QImage::Format_ARGB32_Premultiplied);
+	image.fill(fallback.rgb());
 	{
-		QCryptographicHash hash(QCryptographicHash::Sha1);
-		QFile file(image);
-		if (file.open(QFile::ReadOnly)) {
-			hash.addData(&file);
-			file.close();
+		QPainter painter(&image);
+		painter.drawImage(0, 0, reader.read());
+	}
+	const unsigned int width = image.width();
+	const unsigned int height = image.height();
+
+	quint64 sum_r = 0;
+	quint64 sum_g = 0;
+	quint64 sum_b = 0;
+	quint64 sum_a = 0;
+
+	for (unsigned int y = 0; y < height; ++y) {
+		const QRgb* scanline = reinterpret_cast<const QRgb*>(image.scanLine(y));
+		for (unsigned int x = 0; x < width; ++x) {
+			const QRgb pixel = scanline[x];
+			sum_r += qRed(pixel);
+			sum_g += qGreen(pixel);
+			sum_b += qBlue(pixel);
+			sum_a += qAlpha(pixel);
 		}
-
-		const QString suffix = QFileInfo(image).suffix().toLower();
-
-		return "2-" + hash.result().toHex() + "." + suffix;
 	}
 
-	QString copyImage(const QString& image)
-	{
-		const QString name = checksumName(image);
-		const QString path = Theme::path() + "/Images/" + name;
-		if (!QFile::exists(path)) {
-			QFile::copy(image, path);
-		}
-		return name;
+	const qreal divisor = 1.0 / (width * height);
+	return QColor(sum_r * divisor, sum_g * divisor, sum_b * divisor, sum_a * divisor);
+}
+
+QString checksumName(const QString& image)
+{
+	QCryptographicHash hash(QCryptographicHash::Sha1);
+	QFile file(image);
+	if (file.open(QFile::ReadOnly)) {
+		hash.addData(&file);
+		file.close();
 	}
 
-	QDir listIcons(const QString& id, bool is_default)
-	{
-		const QString icon = Theme::iconPath(id, is_default, 1.0);
+	const QString suffix = QFileInfo(image).suffix().toLower();
 
-		const int dirindex = icon.lastIndexOf('/');
-		const int baseindex = icon.lastIndexOf('.');
-		const QString basename = icon.mid(dirindex + 1, baseindex - dirindex - 1);
+	return "2-" + hash.result().toHex() + "." + suffix;
+}
 
-		return QDir(icon.left(dirindex), basename + "*");
+QString copyImage(const QString& image)
+{
+	const QString name = checksumName(image);
+	const QString path = Theme::path() + "/Images/" + name;
+	if (!QFile::exists(path)) {
+		QFile::copy(image, path);
 	}
+	return name;
+}
+
+QDir listIcons(const QString& id, bool is_default)
+{
+	const QString icon = Theme::iconPath(id, is_default, 1.0);
+
+	const int dirindex = icon.lastIndexOf('/');
+	const int baseindex = icon.lastIndexOf('.');
+	const QString basename = icon.mid(dirindex + 1, baseindex - dirindex - 1);
+
+	return QDir(icon.left(dirindex), basename + "*");
+}
+
 }
 
 //-----------------------------------------------------------------------------
@@ -122,26 +111,26 @@ QString Theme::m_path;
 
 //-----------------------------------------------------------------------------
 
-Theme::ThemeData::ThemeData(const QString& theme_id, bool theme_default, bool create) :
-	id(theme_id),
-	is_default(theme_default),
-	background_type(0, 5),
-	foreground_opacity(0, 100),
-	foreground_width(500, 9999),
-	foreground_margin(1, 250),
-	foreground_padding(0, 250),
-	foreground_position(0, 3),
-	round_corners_enabled(false),
-	corner_radius(1, 100),
-	blur_enabled(false),
-	blur_radius(1, 128),
-	shadow_enabled(false),
-	shadow_offset(0, 128),
-	shadow_radius(1, 128),
-	line_spacing(50, 1000),
-	paragraph_spacing_above(0, 1000),
-	paragraph_spacing_below(0, 1000),
-	tab_width(1, 1000)
+Theme::ThemeData::ThemeData(const QString& theme_id, bool theme_default, bool create)
+	: id(theme_id)
+	, is_default(theme_default)
+	, background_type(0, 5)
+	, foreground_opacity(0, 100)
+	, foreground_width(500, 9999)
+	, foreground_margin(1, 250)
+	, foreground_padding(0, 250)
+	, foreground_position(0, 3)
+	, round_corners_enabled(false)
+	, corner_radius(1, 100)
+	, blur_enabled(false)
+	, blur_radius(1, 128)
+	, shadow_enabled(false)
+	, shadow_offset(0, 128)
+	, shadow_radius(1, 128)
+	, line_spacing(50, 1000)
+	, paragraph_spacing_above(0, 1000)
+	, paragraph_spacing_below(0, 1000)
+	, tab_width(1, 1000)
 {
 	if (id.isEmpty() && create) {
 		QString untitled;
@@ -164,8 +153,8 @@ Theme::Theme()
 
 //-----------------------------------------------------------------------------
 
-Theme::Theme(const Theme& theme) :
-	d(theme.d)
+Theme::Theme(const Theme& theme)
+	: d(theme.d)
 {
 }
 
@@ -200,7 +189,7 @@ QString Theme::clone(const QString& id, bool is_default, const QString& name)
 	}
 
 	// Find name for duplicate theme
-	QStringList values = splitStringAtLastNumber(name);
+	const QStringList values = splitStringAtLastNumber(name);
 	int count = values.at(1).toInt();
 	QString new_name;
 	do {
@@ -209,7 +198,7 @@ QString Theme::clone(const QString& id, bool is_default, const QString& name)
 	} while (exists(new_name));
 
 	// Create duplicate
-	QString new_id = createId();
+	const QString new_id = createId();
 	{
 		Theme duplicate(id, is_default);
 		duplicate.setValue(duplicate.d->name, new_name);
@@ -219,7 +208,7 @@ QString Theme::clone(const QString& id, bool is_default, const QString& name)
 
 	// Copy icon
 	const QDir dir = listIcons(id, is_default);
-	const int suffix = dir.nameFilters().first().length() -1;
+	const int suffix = dir.nameFilters().constFirst().length() -1;
 	const QStringList files = dir.entryList();
 	for (const QString& file : files) {
 		QFile::copy(dir.filePath(file), dir.filePath(new_id + file.mid(suffix)));
@@ -235,7 +224,7 @@ void Theme::copyBackgrounds()
 	QDir dir(path() + "/Images");
 	QStringList images;
 	QHash<QString, QString> old_images;
-	const QHash<QString, QString> source_images = {
+	static const QHash<QString, QString> source_images{
 		{ "2-77534bf3da7fb42c830772be8d279be79869deb7.jpg", m_path_default + "/images/spacedreams.jpg" },
 		{ "2-1ccf9867f755b306830852e8fbf36952f93ab3fe.jpg", m_path_default + "/images/writingdesk.jpg" }
 	};
@@ -244,7 +233,7 @@ void Theme::copyBackgrounds()
 	const QStringList themes = QDir(path(), "*.theme").entryList(QDir::Files);
 	for (const QString& theme : themes) {
 		QSettings settings(path() + "/" + theme, QSettings::IniFormat);
-		QString background_path = settings.value("Background/Image").toString();
+		const QString background_path = settings.value("Background/Image").toString();
 		QString background_image = settings.value("Background/ImageFile").toString();
 		if (background_path.isEmpty() && background_image.isEmpty()) {
 			continue;
@@ -299,10 +288,10 @@ QString Theme::createId()
 
 bool Theme::exists(const QString& name)
 {
-	QDir dir(m_path, "*.theme");
-	QStringList themes = dir.entryList(QDir::Files);
+	const QDir dir(m_path, "*.theme");
+	const QStringList themes = dir.entryList(QDir::Files);
 	for (const QString& theme : themes) {
-		QSettings settings(dir.filePath(theme), QSettings::IniFormat);
+		const QSettings settings(dir.filePath(theme), QSettings::IniFormat);
 		if (settings.value("Name").toString() == name) {
 			return true;
 		}
@@ -430,9 +419,9 @@ QImage Theme::render(const QSize& background, QRect& foreground, const int margi
 	}
 
 	// Draw drop shadow
-	int shadow_radius = shadowEnabled() ? shadowRadius() : 0;
+	const int shadow_radius = shadowEnabled() ? shadowRadius() : 0;
 	if (shadow_radius) {
-		QImage copy = image.copy(QRect(foreground.topLeft() * pixelratio, foreground.bottomRight() * pixelratio));
+		const QImage copy = image.copy(QRect(foreground.topLeft() * pixelratio, foreground.bottomRight() * pixelratio));
 
 		QImage shadow(background, QImage::Format_ARGB32_Premultiplied);
 		shadow.fill(0);
@@ -477,11 +466,11 @@ void Theme::renderText(QImage background, const QRect& foreground, const qreal p
 	}
 
 	// Position preview text
-	int padding = foregroundPadding();
-	int x = foreground.x() + padding;
-	int y = foreground.y() + padding + spacingAboveParagraph();
-	int width = foreground.width() - (padding * 2);
-	int height = foreground.height() - (padding * 2) - spacingAboveParagraph();
+	const int padding = foregroundPadding();
+	const int x = foreground.x() + padding;
+	const int y = foreground.y() + padding + spacingAboveParagraph();
+	const int width = foreground.width() - (padding * 2);
+	const int height = foreground.height() - (padding * 2) - spacingAboveParagraph();
 	preview_text.setGeometry(x, y, width, height);
 
 	// Set colors
@@ -497,7 +486,7 @@ void Theme::renderText(QImage background, const QRect& foreground, const qreal p
 	preview_text.setPalette(p);
 
 	// Set spacings
-	int tab_width = tabWidth();
+	const int tab_width = tabWidth();
 	QTextBlockFormat block_format;
 	block_format.setLineHeight(lineSpacing(), (lineSpacing() == 100) ? QTextBlockFormat::SingleHeight : QTextBlockFormat::ProportionalHeight);
 	block_format.setTextIndent(tab_width * indentFirstLine());
@@ -510,11 +499,7 @@ void Theme::renderText(QImage background, const QRect& foreground, const qreal p
 			f.merge(block_format);
 		}
 	}
-#if (QT_VERSION >= QT_VERSION_CHECK(5,10,0))
 	preview_text.setTabStopDistance(tab_width);
-#else
-	preview_text.setTabStopWidth(tab_width);
-#endif
 	preview_text.document()->setIndentWidth(tab_width);
 
 	// Set font
@@ -535,8 +520,8 @@ void Theme::renderText(QImage background, const QRect& foreground, const qreal p
 		painter.fillRect(QRectF(24, 48, 166, 114), Qt::white);
 
 		// Draw text cutout
-		int x2 = (x >= 24) ? (x - 24) : 0;
-		int y2 = (y >= 24) ? (y - 24) : 0;
+		const int x2 = (x >= 24) ? (x - 24) : 0;
+		const int y2 = (y >= 24) ? (y - 24) : 0;
 		painter.drawImage(QPointF(26, 50), background, QRectF(x2 * pixelratio, y2 * pixelratio, 162 * pixelratio, 110 * pixelratio));
 	}
 
@@ -568,8 +553,8 @@ void Theme::renderText(QImage background, const QRect& foreground, const qreal p
 		painter.fillRect(QRectF(21, 33, 83, 57), Qt::white);
 
 		// Draw text cutout
-		int x2 = (x >= 24) ? (x - 12 + tabWidth()) : 12 + tabWidth();
-		int y2 = (y >= 24) ? (y - 6) : 0;
+		const int x2 = (x >= 24) ? (x - 12 + tabWidth()) : 12 + tabWidth();
+		const int y2 = (y >= 24) ? (y - 6) : 0;
 		painter.drawImage(QPointF(22, 34), background, QRectF(x2 * pixelratio, y2 * pixelratio, 81 * pixelratio, 55 * pixelratio));
 	}
 }
@@ -691,7 +676,7 @@ void Theme::reload()
 		return;
 	}
 
-	QSettings settings(filePath(d->id, d->is_default), QSettings::IniFormat);
+	const QSettings settings(filePath(d->id, d->is_default), QSettings::IniFormat);
 
 	d->name = settings.value("Name", d->name).toString();
 
@@ -714,7 +699,7 @@ void Theme::reload()
 	d->foreground_padding = settings.value("Foreground/Padding", 10).toInt();
 	d->foreground_position = settings.value("Foreground/Position", 1).toInt();
 
-	int rounding = settings.value("Foreground/Rounding", 0).toInt();
+	const int rounding = settings.value("Foreground/Rounding", 0).toInt();
 	if (rounding > 0) {
 		d->round_corners_enabled = true;
 		d->corner_radius = rounding;
