@@ -29,20 +29,6 @@
 </context>
 <context>
     <name>DailyProgress</name>
-    <message numerus="yes">
-        <source>%L1% of %Ln minute(s)</source>
-        <translation>
-            <numerusform>%L1% de %Ln minuto</numerusform>
-            <numerusform>%L1% de %Ln minutoj</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%L1% of %Ln word(s)</source>
-        <translation>
-            <numerusform>%L1% de %Ln vorto</numerusform>
-            <numerusform>%L1% de %Ln vortoj</numerusform>
-        </translation>
-    </message>
     <message numerus="yes">
         <source>%Ln word(s)</source>
         <translation>
@@ -61,6 +47,20 @@
         <source>0%</source>
         <translation>0%</translation>
     </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln minute(s)</source>
+        <translation>
+            <numerusform>%L1% de %Ln minuto</numerusform>
+            <numerusform>%L1% de %Ln minutoj</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln word(s)</source>
+        <translation>
+            <numerusform>%L1% de %Ln vorto</numerusform>
+            <numerusform>%L1% de %Ln vortoj</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>DailyProgressDialog</name>
@@ -334,8 +334,8 @@
         <translation>Malfermi Bildon</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Bildoj(%1)</translation>
+        <source>Images</source>
+        <translation>Bildoj</translation>
     </message>
 </context>
 <context>
@@ -1854,4 +1854,11 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
