@@ -20,7 +20,7 @@
     <name>AlertLayer</name>
     <message>
         <source>Dismiss Alert</source>
-        <translation>Stäng varning</translation>
+        <translation>Avvisa varning</translation>
     </message>
     <message>
         <source>Ctrl+D</source>
@@ -334,8 +334,8 @@
         <translation>Öppna bild</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Bilder(%1)</translation>
+        <source>Images</source>
+        <translation>Bilder</translation>
     </message>
 </context>
 <context>
@@ -408,11 +408,11 @@
     </message>
     <message>
         <source>Shortcuts</source>
-        <translation>Kortkommandon</translation>
+        <translation>Genvägar</translation>
     </message>
     <message>
         <source>One or more shortcuts conflict. Do you wish to proceed?</source>
-        <translation>Kortkommandon i konflikt. Vill du fortsätta?</translation>
+        <translation>En eller flera genvägar i konflikt. Vill du fortsätta?</translation>
     </message>
     <message>
         <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
@@ -448,7 +448,7 @@
     </message>
     <message>
         <source>Smooth fonts</source>
-        <translation>Mjuka typsnitt</translation>
+        <translation>Mjuka teckensnitt</translation>
     </message>
     <message>
         <source>Typewriter sounds</source>
@@ -588,11 +588,11 @@
     </message>
     <message>
         <source>Move Up</source>
-        <translation>Flytta uppåt</translation>
+        <translation>Flytta upp</translation>
     </message>
     <message>
         <source>Move Down</source>
-        <translation>Flytta nedåt</translation>
+        <translation>Flytta ner</translation>
     </message>
     <message>
         <source>Add Separator</source>
@@ -604,7 +604,7 @@
     </message>
     <message>
         <source>Shortcut</source>
-        <translation>Kortkommando</translation>
+        <translation>Genväg</translation>
     </message>
     <message>
         <source>Action</source>
@@ -810,11 +810,11 @@
     </message>
     <message>
         <source>Reset to Default</source>
-        <translation>Återställ till förval</translation>
+        <translation>Återställ till standard</translation>
     </message>
     <message>
         <source>Shortcut:</source>
-        <translation>Kortkommando:</translation>
+        <translation>Genväg:</translation>
     </message>
 </context>
 <context>
@@ -1060,7 +1060,7 @@
     </message>
     <message>
         <source>Font:</source>
-        <translation>Typsnitt:</translation>
+        <translation>Teckensnitt:</translation>
     </message>
     <message>
         <source>Misspelled:</source>
@@ -1854,4 +1854,11 @@
         <translation>Ctrl+Skift+`</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation>Filer att öppna i aktuell session.</translation>
+    </message>
+</context>
 </TS>
