@@ -340,8 +340,8 @@
         <translation>Відкрити зображення</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Зображень(%1)</translation>
+        <source>Images</source>
+        <translation>Зображень</translation>
     </message>
 </context>
 <context>
@@ -1860,4 +1860,11 @@
         <translation>Ctrl+Shift+`</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation>Файли для відкриття в поточному сеансі.</translation>
+    </message>
+</context>
 </TS>
